Module command

Module command 

Command definition, builder, handler type, and parsed command output.

Structs

Command
A command in the registry, potentially with subcommands.
CommandBuilder
Consuming builder for Command.
ParsedCommand
The result of successfully parsing an invocation against a Command.

Type Aliases

AsyncHandlerFn
An async handler function that can be registered on a Command.
HandlerFn
A handler function that can be registered on a Command.